#include <iostream>
#include <algorithm>
#include <vector>
#include <queue>

#define int long long

const int N = 3e5 + 7;
const int INF = 1e18;

std::vector<std::pair<int, int>> g[N];
std::pair<int, int> dist[N];
int p[N];

void dijkstra(int s) {
    using Node = std::pair<std::pair<int, int>, int>;

    for (int i = 0; i < N; ++i) {
        dist[i] = {INF, 0};
    }
    dist[s] = {0, 1};

    std::priority_queue<Node, std::vector<Node>, std::greater<Node>> q;
    q.push({{0, -1}, s});

    while (!q.empty()) {
        std::pair<int, int> dv = q.top().first;
        int v = q.top().second;
        q.pop();

        if (dist[v].first < dv.first || dist[v].second > -dv.second) {
            continue;
        }

        for (auto edge : g[v]) {
            int u = edge.first, w = edge.second;

            if (dist[u].first > dist[v].first + w ||
            (dist[u].first == dist[v].first + w && dist[u].second < dist[v].second + 1)) {
                dist[u] = {dist[v].first + w, dist[v].second + 1};
                p[u] = v;
                q.push({ {dist[u].first, -dist[u].second}, u });
            }
        }
    }
}

void solve() {
    int n, m, s, t;
    std::cin >> n >> m;
    std::cin >> s >> t;

    for (int i = 0; i < m; ++i) {
        int a, b, c;
        std::cin >> a >> b >> c;

        g[a].emplace_back(b, c);
        g[b].emplace_back(a, c);
    }

    dijkstra(s);

    std::cout << dist[t].first << std::endl;
    std::cout << dist[t].second - 2 << std::endl;

    std::vector<int> path;
    for (int v = p[t]; v != s; v = p[v]) {
        path.emplace_back(v);
    }
    std::reverse(path.begin(), path.end());

    for (int v : path) {
        std::cout << v << " ";
    }
}

signed main() {
    std::ios::sync_with_stdio(false);
    std::cin.tie(0);
    std::cout.tie(0);

    solve();

    return 0;
}